intervaltreetools.calculate_density_of_attacks_in_interval
==========================================================

.. autofunction:: abjad.tools.intervaltreetools.calculate_density_of_attacks_in_interval
